@@ -43,7 +43,8 @@ isCmakeInstalled <- function() {
     cat(" - installr::install.cmake()  (Windows; inside the R console)\n")
     cat(" - yum install cmake          (Fedora/CentOS; inside a terminal)\n")
     cat(" - apt install cmake          (Debian/Ubuntu; inside a terminal)\n")
-    cat(" - brew install cmake         (MacOS; inside a terminal with homebrew)\n")
+    cat(" - brew install cmake         (MacOS; inside a terminal with Homebrew)\n")
+    cat(" - port install cmake         (MacOS; inside a terminal with MacPorts)\n")
     cat("\n")
     cat("Alternatively install CMake from: <https://cmake.org/>\n")
     cat("\n")
@@ -108,16 +109,21 @@ installOpenCV <- function(batch = FALSE) {
     openCVPath <- paste0(installPath, "opencv")
     message(paste0("OpenCV will be installed in ", openCVPath))
 
+    if (dir.exists(openCVPath)) {
+      message("Removing old OpenCV installation.")
+      unlink(openCVPath, recursive = TRUE)
+    }
+
     Sys.setenv(CXX_STD = "CXX11")
 
     if (.Platform$OS.type == "windows") {
       dir.create(openCVPath, showWarnings = FALSE)
-      tmpDir <- base::tempdir()
+      tmpDir <- gsub("\\\\", "/", base::tempdir())
       dir.create(tmpDir, showWarnings = FALSE)
 
-      utils::download.file("https://github.com/opencv/opencv/archive/4.1.2.tar.gz",
-                           paste0(tmpDir, "/opencv-4.1.2.tar.gz"))
-      utils::untar(paste0(tmpDir, "/opencv-4.1.2.tar.gz"),
+      utils::download.file("https://github.com/opencv/opencv/archive/4.3.0.tar.gz",
+                           paste0(tmpDir, "/opencv-4.3.0.tar.gz"))
+      utils::untar(paste0(tmpDir, "/opencv-4.3.0.tar.gz"),
                    exdir = tmpDir)
 
       arch <- c("64", "32")
@@ -127,17 +133,33 @@ installOpenCV <- function(batch = FALSE) {
       if (any(archAvail)) {
         pkgbuild::check_rtools()
         rtoolsPath <- gsub("/bin", "", pkgbuild::rtools_path())
+        rtoolsPath <- gsub("\\\\", "/", rtoolsPath)
+        rtools4 <- grepl("usr", rtoolsPath)
 
         for (i in 1:2) {
-          if (archAvail[i]) {
-            sourceDir <- paste0(tmpDir, "/opencv-4.1.2/")
+          if (archAvail[i] == TRUE) {
+            sourceDir <- paste0(tmpDir, "/opencv-4.3.0/")
             buildDir <- paste0(sourceDir, "build", arch[i])
             dir.create(buildDir, showWarnings = FALSE)
-            system(paste0('cmake -G "Unix Makefiles" -DCMAKE_C_COMPILER=', rtoolsPath, '/mingw_', arch[i], '/bin/gcc.exe -DCMAKE_CXX_COMPILER=', rtoolsPath, '/mingw_', arch[i], '/bin/g++.exe -DCMAKE_RC_COMPILER=', rtoolsPath, '/mingw_', arch[i], '/bin/windres.exe -DCMAKE_MAKE_PROGRAM=', rtoolsPath, '/mingw_', arch[i], '/bin/mingw32-make.exe -DENABLE_PRECOMPILED_HEADERS=OFF -DENABLE_CXX11=ON -DBUILD_ZLIB=ON -DBUILD_opencv_world=OFF -DBUILD_opencv_contrib_world=OFF -DBUILD_matlab=OFF -DBUILD_opencv_java=OFF -DBUILD_opencv_python2=OFF -DBUILD_opencv_python3=OFF -DBUILD_PERF_TESTS=OFF -DBUILD_TESTS=OFF -DWITH_MSMF=OFF -DBUILD_PROTOBUF=OFF -DBUILD_SHARED_LIBS=ON -DCMAKE_BUILD_TYPE=RELEASE -DCMAKE_INSTALL_PREFIX=', openCVPath, ' -B', buildDir, ' -H', sourceDir))
-            system(paste0(rtoolsPath, "/mingw_", arch[i], "/bin/mingw32-make.exe -j",
-                          parallel::detectCores(), " -C ", buildDir))
-            system(paste0(rtoolsPath, "/mingw_", arch[i], "/bin/mingw32-make.exe -C",
-                          buildDir, " install"))
+
+            if (rtools4) {
+              rtools4Path <- gsub("/usr", "", rtoolsPath)
+              gcc_path <- paste0(rtools4Path, "/mingw", arch[i], "/bin/gcc.exe")
+              gpp_path <- paste0(rtools4Path, "/mingw", arch[i], "/bin/g++.exe")
+              windres_path <- paste0(rtools4Path, "/mingw", arch[i], "/bin/windres.exe")
+              make_path <- paste0(rtools4Path, "/usr/bin/make.exe")
+            } else {
+              gcc_path <- paste0(rtoolsPath, "/mingw_", arch[i], "/bin/gcc.exe")
+              gpp_path <- paste0(rtoolsPath, "/mingw_", arch[i], "/bin/g++.exe")
+              windres_path <- paste0(rtoolsPath, "/mingw_", arch[i], "/bin/windres.exe")
+              make_path <- paste0(rtoolsPath, "/mingw_", arch[i], "/bin/mingw32-make.exe")
+            }
+
+            openCVArch <- if (arch[i] == 64) "x64" else "x86"
+
+            system(paste0('cmake -G "Unix Makefiles" -DCMAKE_C_COMPILER=', gcc_path, ' -DCMAKE_CXX_COMPILER=', gpp_path, ' -DCMAKE_RC_COMPILER=', windres_path, ' -DCMAKE_MAKE_PROGRAM=', make_path, ' -DENABLE_PRECOMPILED_HEADERS=OFF -DOpenCV_ARCH=', openCVArch, ' -DOpenCV_RUNTIME=mingw -DENABLE_CXX11=ON -DBUILD_ZLIB=ON -DBUILD_opencv_world=OFF -DBUILD_opencv_contrib_world=OFF -DBUILD_matlab=OFF -DBUILD_opencv_java=OFF -DBUILD_opencv_python2=OFF -DBUILD_opencv_python3=OFF -DBUILD_PERF_TESTS=OFF -DBUILD_TESTS=OFF -DWITH_MSMF=OFF -DBUILD_PROTOBUF=OFF -DOPENCV_ENABLE_ALLOCATOR_STATS=OFF -DBUILD_SHARED_LIBS=ON -DCMAKE_BUILD_TYPE=RELEASE -DCMAKE_INSTALL_PREFIX=', openCVPath, ' -B', buildDir, ' -H', sourceDir))
+            system(paste0(make_path, " -j", parallel::detectCores(), " -C ", buildDir))
+            system(paste0(make_path, " -C", buildDir, " install"))
           }
         }
       }
@@ -146,16 +168,16 @@ installOpenCV <- function(batch = FALSE) {
       tmpDir <- base::tempdir()
       dir.create(tmpDir, showWarnings = FALSE)
 
-      utils::download.file("https://github.com/opencv/opencv/archive/4.1.2.zip",
-                           paste0(tmpDir, "/opencv-4.1.2.zip"))
-      utils::unzip(paste0(tmpDir, "/opencv-4.1.2.zip"),
+      utils::download.file("https://github.com/opencv/opencv/archive/4.3.0.zip",
+                           paste0(tmpDir, "/opencv-4.3.0.zip"))
+      utils::unzip(paste0(tmpDir, "/opencv-4.3.0.zip"),
                    exdir = tmpDir)
 
-      file.copy(paste0(pkgPath, "/OpenCVModule.4.1.2.cmake"),
-                paste0(tmpDir, "/opencv-4.1.2/cmake/OpenCVModule.cmake"),
+      file.copy(paste0(pkgPath, "/OpenCVModule.4.3.0.cmake"),
+                paste0(tmpDir, "/opencv-4.3.0/cmake/OpenCVModule.cmake"),
                 overwrite = TRUE)
 
-      sourceDir <- paste0(tmpDir, "/opencv-4.1.2/")
+      sourceDir <- paste0(tmpDir, "/opencv-4.3.0/")
       buildDir <- paste0(sourceDir, "build")
       dir.create(buildDir, showWarnings = FALSE)
       system(paste0("cmake -DWITH_IPP=ON -DBUILD_opencv_world=OFF -DBUILD_opencv_contrib_world=OFF -DBUILD_opencv_matlab=OFF -DBUILD_opencv_java=OFF -DBUILD_opencv_python2=OFF -DBUILD_opencv_python3=OFF -DBUILD_PERF_TESTS=OFF -DBUILD_TESTS=OFF -DINSTALL_CREATE_DISTRIB=ON -DCMAKE_BUILD_TYPE=RELEASE -DCMAKE_INSTALL_PREFIX=", openCVPath, " -B", buildDir, ' -H', sourceDir))
